@@ -222,7 +222,7 @@ match_key (Key *key, XEvent *event)
 		group = (event->xkey.state & GDK_KEY_Mode_switch) ? 1 : 0;
 
 	/* Check if we find a keysym that matches our current state */
-	if (gdk_keymap_translate_keyboard_state (NULL, event->xkey.keycode,
+	if (gdk_keymap_translate_keyboard_state (gdk_keymap_get_default(), event->xkey.keycode,
 					     event->xkey.state, group,
 					     &keyval, NULL, NULL, &consumed)) {
 		guint lower, upper;
