@@ -17,20 +17,17 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301, USA.
  */
 
 #ifndef __MSD_KEYBOARD_XKB_H
 #define __MSD_KEYBOARD_XKB_H
 
-#include <mateconf/mateconf.h>
-#include <mateconf/mateconf-client.h>
-
 #include <libxklavier/xklavier.h>
 #include "msd-keyboard-manager.h"
 
-void msd_keyboard_xkb_init(MateConfClient* client, MsdKeyboardManager* manager);
+void msd_keyboard_xkb_init(MsdKeyboardManager* manager);
 void msd_keyboard_xkb_shutdown(void);
 
 typedef void (*PostActivationCallback) (void* userData);
